contexttools.get_dynamic_mark_attached_to_component
===================================================

.. autofunction:: abjad.tools.contexttools.get_dynamic_mark_attached_to_component.get_dynamic_mark_attached_to_component
